@@ -1,6 +1,6 @@
 import requests
 import xml.etree.ElementTree as ET
-from util.getters import get_connected_sim
+from .util.getters import get_connected_sim
 
 
 def disconnect_sim(mssb_ip, mssb_serial, slot_terminal):
